API
===

.. autosummary::
   :toctree: generated

   pyytlounge.YtLoungeApi
   pyytlounge.EventListener
   pyytlounge.PlaybackStateEvent
   pyytlounge.NowPlayingEvent
   pyytlounge.VolumeChangedEvent
   pyytlounge.AutoplayModeChangedEvent
   pyytlounge.State
   pyytlounge.get_thumbnail_url
   pyytlounge.dial.get_screen_id_from_dial
